==> apeman-api-path-1.1.0.tgz: package/test/define_test.js <==
/**
 * Test case for define.
 * Runs with mocha.
 */
'use strict'

const define = require('../lib/define.js')
const assert = require('assert')
const { moduleProxy } = require('rfunc-mock')
const co = require('co')

describe('define', function () {
  this.timeout(3000)

  before(() => co(function * () {

  }))

  after(() => co(function * () {

  }))

  it('Ping pong', () => co(function * () {
    let module = define({
      logging: true
    })
    let api = moduleProxy(module, { ctx: { state: {} } })
    let pong = yield api.ping('The pong!')
    assert.equal(pong, 'The pong!')
  }))

  it('Resolve paths', () => co(function * () {
    let module = define({
      logging: true
    })
    let api = moduleProxy(module, { ctx: { state: {} } })
    {
      let basename = yield api.basename('hoge.txt', '.txt')
      assert.equal(basename, 'hoge')

      let dirname = yield api.dirname('foo/bar/baz.txt')
      assert.equal(dirname, 'foo/bar')

      let relative = yield api.relative('foo/bar', 'foo/baz/quz.txt')
      assert.equal(relative, '../baz/quz.txt')
    }
    {
      let resolved = yield api.resolve('foo')
      assert.equal(resolved, 'foo')
    }
    {
      let resolved = yield api.resolve('foo/bar', '../baz')
      assert.equal(resolved, 'foo/baz')
    }
    {
      let caught
      try {
        yield api.resolve('foo', '/usr/lib/bin')
      } catch (err) {
        caught = err
      }
      assert.ok(caught)
    }
  }))

  it('Compare spec and implement', () => co(function * () {
    let module = define({
      logging: false
    })
    let implNames = Object.keys(module).filter((name) => !/^\$/.test(name))
    let specNames = Object.keys(module.$spec)
    for (let implName of implNames) {
      assert.ok(!!~specNames.indexOf(implName), `${implName} is implemented, but not described in "$spec"`)
    }
    for (let specName of specNames) {
      assert.ok(!!~implNames.indexOf(specName), `${specName} is described in "$spec", but not implemented`)
    }
  }))
})

/* global describe, before, after, it */

==> apeman-api-path-1.1.3.tgz: package/test/define_test.js <==
/**
 * Test case for define.
 * Runs with mocha.
 */
'use strict'

const define = require('../lib/define.js')
const assert = require('assert')
const { moduleProxy } = require('apemanmock')
const co = require('co')

describe('define', function () {
  this.timeout(3000)

  before(() => co(function * () {

  }))

  after(() => co(function * () {

  }))

  it('Ping pong', () => co(function * () {
    let module = define({
      logging: true
    })
    let api = moduleProxy(module, { ctx: { state: {} } })
    let pong = yield api.ping('The pong!')
    assert.equal(pong, 'The pong!')
  }))

  it('Resolve paths', () => co(function * () {
    let module = define({
      logging: true
    })
    let api = moduleProxy(module, { ctx: { state: {} } })
    {
      let basename = yield api.basename('hoge.txt', '.txt')
      assert.equal(basename, 'hoge')

      let dirname = yield api.dirname('foo/bar/baz.txt')
      assert.equal(dirname, 'foo/bar')

      let relative = yield api.relative('foo/bar', 'foo/baz/quz.txt')
      assert.equal(relative, '../baz/quz.txt')
    }
    {
      let resolved = yield api.resolve('foo')
      assert.equal(resolved, 'foo')
    }
    {
      let resolved = yield api.resolve('foo/bar', '../baz')
      assert.equal(resolved, 'foo/baz')
    }
    {
      let caught
      try {
        yield api.resolve('foo', '/usr/lib/bin')
      } catch (err) {
        caught = err
      }
      assert.ok(caught)
    }
  }))

  it('Compare spec and implement', () => co(function * () {
    let module = define({
      logging: false
    })
    let implNames = Object.keys(module).filter((name) => !/^\$/.test(name))
    let specNames = Object.keys(module.$spec)
    for (let implName of implNames) {
      assert.ok(!!~specNames.indexOf(implName), `${implName} is implemented, but not described in "$spec"`)
    }
    for (let specName of specNames) {
      assert.ok(!!~implNames.indexOf(specName), `${specName} is described in "$spec", but not implemented`)
    }
  }))
})

/* global describe, before, after, it */
